@@ -1,10 +1,14 @@
 # -*- coding: utf-8 -*-
 
+import logging
+
 from .exceptions import PoyoException
 from .parser import parse_string
 
 __author__ = 'Raphael Pierzina'
 __email__ = 'raphael@hackebrot.de'
-__version__ = '0.3.0'
+__version__ = '0.4.0'
+
+logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 __all__ = ['parse_string', 'PoyoException']
